Enum lsp_types::MarkedString [−][src]
pub enum MarkedString {
String(String),
LanguageString(LanguageString),
}Expand description
The marked string is rendered:
- as markdown if it is represented as a string
- as code block of the given langauge if it is represented as a pair of a language and a value
The pair of a language and a value is an equivalent to markdown:
${language} ${value}
Variants
String(String)LanguageString(LanguageString)Implementations