Enum lsp_types::MonikerKind [−][src]
pub enum MonikerKind {
Import,
Export,
Local,
}Expand description
The moniker kind.
Variants
The moniker represent a symbol that is imported into a project
The moniker represent a symbol that is exported into a project
The moniker represents a symbol that is local to a project (e.g. a local variable of a function, a class not visible outside the project, …)