pub enum TraceValue {
    Off,
    Messages,
    Verbose,
}
A TraceValue represents the level of verbosity with which the server systematically reports its execution trace using LogTrace notifications.

The initial trace value is set by the client at initialization and can be modified later using the SetTrace notification.

Variants

Off

The server should not send any $/logTrace notification

Messages

The server should not add the ‘verbose’ field in the LogTraceParams

Verbose