Enum lsp_types::notification::Initialized [−][src]
pub enum Initialized {}Expand description
The initialized notification is sent from the client to the server after the client received the result of the initialize request but before the client is sending any other request or notification to the server. The server can use the initialized notification for example to dynamically register capabilities.