Enum lsp_types::notification::LogMessage [−][src]
pub enum LogMessage {}Expand description
The log message notification is sent from the server to the client to ask the client to log a particular message.