Enum lsp_types::notification::ShowMessage [−][src]
pub enum ShowMessage {}Expand description
The show message notification is sent from a server to a client to ask the client to display a particular message in the user interface.