Enum lsp_types::request::ApplyWorkspaceEdit [−][src]
pub enum ApplyWorkspaceEdit {}Expand description
The workspace/applyEdit request is sent from the server to the client to modify resource on the client side.