Enum lsp_types::request::CodeLensRequest [−][src]
pub enum CodeLensRequest {}Expand description
The code lens request is sent from the client to the server to compute code lenses for a given text document.