Enum lsp_types::request::GotoDeclaration [−][src]
pub enum GotoDeclaration {}Trait Implementations
The goto declaration request is sent from the client to the server to resolve the declaration location of a symbol at a given text document position.
type Params = GotoDeclarationParamstype Result = Option<GotoDeclarationResponse>Auto Trait Implementations
impl RefUnwindSafe for GotoDeclarationimpl Send for GotoDeclarationimpl Sync for GotoDeclarationimpl Unpin for GotoDeclarationimpl UnwindSafe for GotoDeclaration