Enum lsp_types::request::GotoDefinition [−][src]
pub enum GotoDefinition {}Expand description
The goto definition request is sent from the client to the server to resolve the definition location of a symbol at a given text document position.