Enum lsp_types::request::GotoImplementation [−][src]
pub enum GotoImplementation {}Expand description
The goto implementation request is sent from the client to the server to resolve the implementation location of a symbol at a given text document position.