pub enum InlayHintRefreshRequest {}Expand description
The workspace/inlayHint/refresh request is sent from the server to the client. Servers can use
it to ask clients to refresh the inlay hints currently shown in editors. As a result the client
should ask the server to recompute the inlay hints for these editors. This is useful if a server
detects a configuration change which requires a re-calculation of all inlay hints. Note that the
client still has the freedom to delay the re-calculation of the inlay hints if for example an
editor is currently not visible.