pub enum InlineValueRefreshRequest {}Expand description
The workspace/inlineValue/refresh request is sent from the server to the client. Servers can
use it to ask clients to refresh the inline values currently shown in editors. As a result the
client should ask the server to recompute the inline values for these editors. This is useful if
a server detects a configuration change which requires a re-calculation of all inline values.
Note that the client still has the freedom to delay the re-calculation of the inline values if
for example an editor is currently not visible.