Enum lsp_types::request::OnTypeFormatting [−][src]
pub enum OnTypeFormatting {}Expand description
The document on type formatting request is sent from the client to the server to format parts of the document during typing.