Enum lsp_types::request::RangeFormatting [−][src]
pub enum RangeFormatting {}Expand description
The document range formatting request is sent from the client to the server to format a given range in a document.