Enum lsp_types::request::SemanticTokensRefesh [−][src]
pub enum SemanticTokensRefesh {}Expand description
The workspace/semanticTokens/refresh request is sent from the server to the client.
Servers can use it to ask clients to refresh the editors for which this server provides semantic tokens.
As a result the client should ask the server to recompute the semantic tokens for these editors.
This is useful if a server detects a project wide configuration change which requires a re-calculation of all semantic tokens.
Note that the client still has the freedom to delay the re-calculation of the semantic tokens if for example an editor is currently not visible.