Enum lsp_types::request::ShowMessageRequest [−][src]
pub enum ShowMessageRequest {}Expand description
The show message request is sent from a server to a client to ask the client to display a particular message in the user interface. In addition to the show message notification the request allows to pass actions and to wait for an answer from the client.