Trait lsp_types::request::Request [−][src]
pub trait Request {
type Params: DeserializeOwned + Serialize;
type Result: DeserializeOwned + Serialize;
const METHOD: &'static str;
}Associated Types
type Params: DeserializeOwned + Serialize[src]type Result: DeserializeOwned + Serialize[src]Associated Constants
Implementors
type Params = ApplyWorkspaceEditParamstype Result = ApplyWorkspaceEditResponsetype Result = Option<Vec<CallHierarchyIncomingCall>>type Result = Option<Vec<CallHierarchyOutgoingCall>>type Params = CallHierarchyPrepareParamstype Result = Option<Vec<CallHierarchyItem>>type Params = CodeActionParamstype Result = Option<CodeActionResponse>type Params = ColorPresentationParamstype Result = Vec<ColorPresentation>type Params = CompletionParamstype Result = Option<CompletionResponse>type Params = DocumentHighlightParamstype Result = Option<Vec<DocumentHighlight>>type Params = DocumentLinkParamstype Result = Option<Vec<DocumentLink>>type Params = DocumentSymbolParamstype Result = Option<DocumentSymbolResponse>type Params = FoldingRangeParamstype Result = Option<Vec<FoldingRange>>The goto declaration request is sent from the client to the server to resolve the declaration location of a symbol at a given text document position.
type Params = GotoDeclarationParamstype Result = Option<GotoDeclarationResponse>type Params = GotoDefinitionParamstype Result = Option<GotoDefinitionResponse>type Params = GotoImplementationParamstype Result = Option<GotoImplementationResponse>type Params = GotoTypeDefinitionParamstype Result = Option<GotoTypeDefinitionResponse>type Params = LinkedEditingRangeParamstype Result = Option<LinkedEditingRanges>type Params = TextDocumentPositionParamstype Result = Option<PrepareRenameResponse>type Params = SelectionRangeParamstype Result = Option<Vec<SelectionRange>>type Params = SemanticTokensDeltaParamstype Params = SemanticTokensParamstype Result = Option<SemanticTokensResult>type Params = SemanticTokensRangeParamstype Result = Option<SemanticTokensRangeResult>type Params = ShowMessageRequestParamstype Result = Option<MessageActionItem>type Params = WorkspaceSymbolParamstype Result = Option<Vec<SymbolInformation>>