Struct lsp_types::ApplyWorkspaceEditParams [−][src]
pub struct ApplyWorkspaceEditParams {
pub label: Option<String>,
pub edit: WorkspaceEdit,
}Fields
label: Option<String>An optional label of the workspace edit. This label is presented in the user interface for example on an undo stack to undo the workspace edit.
edit: WorkspaceEditThe edits to apply.