Struct lsp_types::ApplyWorkspaceEditResponse
source · [−]pub struct ApplyWorkspaceEditResponse {
pub applied: bool,
pub failure_reason: Option<String>,
pub failed_change: Option<u32>,
}Fields
applied: boolIndicates whether the edit was applied or not.
failure_reason: Option<String>An optional textual description for why the edit was not applied. This may be used may be used by the server for diagnostic logging or to provide a suitable error for a request that triggered the edit
failed_change: Option<u32>Depending on the client’s failure handling strategy failedChange might
contain the index of the change that failed. This property is only available
if the client signals a failureHandlingStrategy in its client capabilities.