Struct lsp_types::CallHierarchyItem [−][src]
pub struct CallHierarchyItem {
pub name: String,
pub kind: SymbolKind,
pub tags: Option<Vec<SymbolTag>>,
pub detail: Option<String>,
pub uri: Url,
pub range: Range,
pub selection_range: Range,
pub data: Option<Value>,
}Fields
name: StringThe name of this item.
kind: SymbolKindThe kind of this item.
Tags for this item.
detail: Option<String>More detail for this item, e.g. the signature of a function.
uri: UrlThe resource identifier of this item.
range: RangeThe range enclosing this symbol not including leading/trailing whitespace but everything else, e.g. comments and code.
selection_range: RangeThe range that should be selected and revealed when this symbol is being picked, e.g. the name of a function.
Must be contained by the range.
data: Option<Value>A data entry field that is preserved between a call hierarchy prepare and incloming calls or outgoing calls requests.