Struct lsp_types::ChangeAnnotation [−][src]
pub struct ChangeAnnotation {
pub label: String,
pub needs_confirmation: Option<bool>,
pub description: Option<String>,
}Expand description
Additional information that describes document changes.
@since 3.16.0.
Fields
label: StringA human-readable string describing the actual change. The string is rendered prominent in the user interface.
needs_confirmation: Option<bool>A flag which indicates that user confirmation is needed before applying the change.
description: Option<String>A human-readable string which is rendered less prominent in the user interface.