Struct lsp_types::CodeActionClientCapabilities [−][src]
Fields
dynamic_registration: Option<bool>This capability supports dynamic registration.
code_action_literal_support: Option<CodeActionLiteralSupport>The client support code action literals as a valid
response of the textDocument/codeAction request.
is_preferred_support: Option<bool>Whether code action supports the isPreferred property.
since 3.15.0
disabled_support: Option<bool>Whether code action supports the disabled property.
since 3.16.0
data_support: Option<bool>Whether code action supports the data property which is
preserved between a textDocument/codeAction and a
codeAction/resolve request.
since 3.16.0
resolve_support: Option<CodeActionCapabilityResolveSupport>Whether the client supports resolving additional code action
properties via a separate codeAction/resolve request.
since 3.16.0
honors_change_annotations: Option<bool>Whether the client honors the change annotations in
text edits and resource operations returned via the
CodeAction#edit property by for example presenting
the workspace edit in the user interface and asking
for confirmation.
@since 3.16.0