Struct lsp_types::CodeActionOptions [−][src]
Fields
code_action_kinds: Option<Vec<CodeActionKind>>CodeActionKinds that this server may return.
The list of kinds may be generic, such as CodeActionKind.Refactor, or the server
may list out every specific kind they provide.
work_done_progress_options: WorkDoneProgressOptionsresolve_provider: Option<bool>The server provides support to resolve additional information for a code action.
since 3.16.0