Struct lsp_types::CodeLens [−][src]
A code lens represents a command that should be shown along with source text, like the number of references, a way to run tests, etc.
A code lens is unresolved when no command is associated to it. For performance reasons the creation of a code lens and resolving should be done in two stages.
Fields
range: RangeThe range in which this code lens is valid. Should only span a single line.
command: Option<Command>The command this code lens represents.
data: Option<Value>A data entry field that is preserved on a code lens item between a code lens and a code lens resolve request.