Struct lsp_types::Command [−][src]
Represents a reference to a command. Provides a title which will be used to represent a command in the UI. Commands are identitifed using a string identifier and the protocol currently doesn’t specify a set of well known commands. So executing a command requires some tool extension code.
Fields
title: StringTitle of the command, like save.
command: StringThe identifier of the actual command handler.
arguments: Option<Vec<Value>>Arguments that the command handler should be invoked with.
Implementations