Struct lsp_types::CompletionOptions [−][src]
pub struct CompletionOptions {
pub resolve_provider: Option<bool>,
pub trigger_characters: Option<Vec<String>>,
pub all_commit_characters: Option<Vec<String>>,
pub work_done_progress_options: WorkDoneProgressOptions,
}Expand description
Completion options.
Fields
resolve_provider: Option<bool>The server provides support to resolve additional information for a completion item.
trigger_characters: Option<Vec<String>>Most tools trigger completion request automatically without explicitly
requesting it using a keyboard shortcut (e.g. Ctrl+Space). Typically they
do so when the user starts to type an identifier. For example if the user
types c in a JavaScript file code complete will automatically pop up
present console besides others as a completion item. Characters that
make up identifiers don’t need to be listed here.
If code complete should automatically be trigger on characters not being
valid inside an identifier (for example . in JavaScript) list them in
triggerCharacters.
all_commit_characters: Option<Vec<String>>The list of all possible characters that commit a completion. This field
can be used if clients don’t support individual commit characters per
completion item. See client capability
completion.completionItem.commitCharactersSupport.
If a server provides both allCommitCharacters and commit characters on
an individual completion item the ones on the completion item win.
@since 3.2.0
work_done_progress_options: WorkDoneProgressOptionsTrait Implementations
Returns the “default value” for a type. Read more
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.