Struct lsp_types::Diagnostic [−][src]
Represents a diagnostic, such as a compiler error or warning. Diagnostic objects are only valid in the scope of a resource.
Fields
range: RangeThe range at which the message applies.
severity: Option<DiagnosticSeverity>The diagnostic's severity. Can be omitted. If omitted it is up to the client to interpret diagnostics as error, warning, info or hint.
code: Option<NumberOrString>The diagnostic's code. Can be omitted.
code_description: Option<CodeDescription>An optional property to describe the error code.
since 3.16.0
source: Option<String>A human-readable string describing the source of this diagnostic, e.g. 'typescript' or 'super lint'.
message: StringThe diagnostic's message.
An array of related diagnostic information, e.g. when symbol-names within a scope collide all definitions can be marked via this property.
Additional metadata about the diagnostic.
data: Option<Value>A data entry field that is preserved between a textDocument/publishDiagnostics
notification and textDocument/codeAction request.
since 3.16.0
Implementations
impl Diagnostic[src]
pub fn new(
range: Range,
severity: Option<DiagnosticSeverity>,
code: Option<NumberOrString>,
source: Option<String>,
message: String,
related_information: Option<Vec<DiagnosticRelatedInformation>>,
tags: Option<Vec<DiagnosticTag>>
) -> Diagnostic[src]
range: Range,
severity: Option<DiagnosticSeverity>,
code: Option<NumberOrString>,
source: Option<String>,
message: String,
related_information: Option<Vec<DiagnosticRelatedInformation>>,
tags: Option<Vec<DiagnosticTag>>
) -> Diagnostic
pub fn new_simple(range: Range, message: String) -> Diagnostic[src]
pub fn new_with_code_number(
range: Range,
severity: DiagnosticSeverity,
code_number: i32,
source: Option<String>,
message: String
) -> Diagnostic[src]
range: Range,
severity: DiagnosticSeverity,
code_number: i32,
source: Option<String>,
message: String
) -> Diagnostic