Struct lsp_types::DocumentHighlight [−][src]
pub struct DocumentHighlight {
pub range: Range,
pub kind: Option<DocumentHighlightKind>,
}Expand description
A document highlight is a range inside a text document which deserves special attention. Usually a document highlight is visualized by changing the background color of its range.
Fields
range: RangeThe range this highlight applies to.
kind: Option<DocumentHighlightKind>The highlight kind, default is DocumentHighlightKind.Text.