Struct lsp_types::DocumentSymbolOptions [−][src]
pub struct DocumentSymbolOptions {
pub label: Option<String>,
pub work_done_progress_options: WorkDoneProgressOptions,
}Fields
label: Option<String>A human-readable string that is shown when multiple outlines trees are shown for the same document.
@since 3.16.0
work_done_progress_options: WorkDoneProgressOptionsTrait Implementations
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.