Struct lsp_types::FileOperationPattern [−][src]
pub struct FileOperationPattern {
pub glob: String,
pub matches: Option<FileOperationPatternKind>,
pub options: Option<FileOperationPatternOptions>,
}Expand description
A pattern to describe in which file operation requests or notifications the server is interested in.
@since 3.16.0
Fields
glob: StringThe glob pattern to match. Glob patterns can have the following syntax:
*to match one or more characters in a path segment?to match on one character in a path segment**to match any number of path segments, including none{}to group conditions (e.g.**/*.{ts,js}matches all TypeScript and JavaScript files)[]to declare a range of characters to match in a path segment (e.g.,example.[0-9]to match onexample.0,example.1, …)[!...]to negate a range of characters to match in a path segment (e.g.,example.[!0-9]to match onexample.a,example.b, but notexample.0)
matches: Option<FileOperationPatternKind>Whether to match files or folders with this pattern.
Matches both if undefined.
options: Option<FileOperationPatternOptions>Additional options used during matching.