Struct lsp_types::FormattingOptions [−][src]
pub struct FormattingOptions {
pub tab_size: u32,
pub insert_spaces: bool,
pub properties: HashMap<String, FormattingProperty>,
pub trim_trailing_whitespace: Option<bool>,
pub insert_final_newline: Option<bool>,
pub trim_final_newlines: Option<bool>,
}Expand description
Value-object describing what options formatting should use.
Fields
tab_size: u32Size of a tab in spaces.
insert_spaces: boolPrefer spaces over tabs.
properties: HashMap<String, FormattingProperty>Signature for further properties.
trim_trailing_whitespace: Option<bool>Trim trailing whitespaces on a line.
insert_final_newline: Option<bool>Insert a newline character at the end of the file if one does not exist.
trim_final_newlines: Option<bool>Trim all newlines after the final newline at the end of the file.