Struct lsp_types::Hover [−][src]
pub struct Hover {
pub contents: HoverContents,
pub range: Option<Range>,
}Expand description
The result of a hover request.
Fields
contents: HoverContentsThe hover’s content
range: Option<Range>An optional range is a range inside a text document that is used to visualize a hover, e.g. by changing the background color.