[−][src]Struct lsp_types::HoverCapability
Fields
dynamic_registration: Option<bool>Whether completion supports dynamic registration.
content_format: Option<Vec<MarkupKind>>Client supports the follow content formats for the content property. The order describes the preferred format of the client.