Struct lsp_types::InitializeError [−][src]
pub struct InitializeError {
pub retry: bool,
}Fields
retry: boolIndicates whether the client should retry to send the initilize request after showing the message provided in the ResponseError.