Struct lsp_types::InitializeParams
source · [−]pub struct InitializeParams {
pub process_id: Option<u32>,
pub root_path: Option<String>,
pub root_uri: Option<Url>,
pub initialization_options: Option<Value>,
pub capabilities: ClientCapabilities,
pub trace: Option<TraceValue>,
pub workspace_folders: Option<Vec<WorkspaceFolder>>,
pub client_info: Option<ClientInfo>,
pub locale: Option<String>,
}Fields
process_id: Option<u32>The process Id of the parent process that started the server. Is null if the process has not been started by another process. If the parent process is not alive then the server should exit (see exit notification) its process.
root_path: Option<String>Use root_uri instead when possible
The rootPath of the workspace. Is null if no folder is open.
root_uri: Option<Url>The rootUri of the workspace. Is null if no
folder is open. If both rootPath and rootUri are set
rootUri wins.
Deprecated in favour of workspaceFolders
initialization_options: Option<Value>User provided initialization options.
capabilities: ClientCapabilitiesThe capabilities provided by the client (editor or tool)
trace: Option<TraceValue>The initial trace setting. If omitted trace is disabled (‘off’).
workspace_folders: Option<Vec<WorkspaceFolder>>The workspace folders configured in the client when the server starts.
This property is only available if the client supports workspace folders.
It can be null if the client supports workspace folders but none are
configured.
client_info: Option<ClientInfo>Information about the client.
locale: Option<String>The locale the client is currently showing the user interface in. This must not necessarily be the locale of the operating system.
Uses IETF language tags as the value’s syntax (See https://en.wikipedia.org/wiki/IETF_language_tag)
@since 3.16.0