Struct lsp_types::LinkedEditingRanges [−][src]
Fields
ranges: Vec<Range>A list of ranges that can be renamed together. The ranges must have identical length and contain identical text content. The ranges cannot overlap.
word_pattern: Option<String>An optional word pattern (regular expression) that describes valid contents for the given ranges. If no pattern is provided, the client configuration’s word pattern will be used.