Struct lsp_types::PartialResultParams [−][src]
pub struct PartialResultParams {
pub partial_result_token: Option<ProgressToken>,
}Expand description
A parameter literal used to pass a partial result token.
Fields
partial_result_token: Option<ProgressToken>Trait Implementations
Returns the “default value” for a type. Read more
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.