Struct lsp_types::ProgressParams [−][src]
pub struct ProgressParams {
pub token: ProgressToken,
pub value: ProgressParamsValue,
}Expand description
The progress notification is sent from the server to the client to ask the client to indicate progress.
Fields
token: ProgressTokenThe progress token provided by the client.
value: ProgressParamsValueThe progress data.