Struct lsp_types::RenameOptions [−][src]
pub struct RenameOptions {
pub prepare_provider: Option<bool>,
pub work_done_progress_options: WorkDoneProgressOptions,
}Fields
prepare_provider: Option<bool>Renames should be checked and tested before being executed.
work_done_progress_options: WorkDoneProgressOptionsTrait Implementations
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.