Struct lsp_types::RenameParams
source · pub struct RenameParams {
pub text_document_position: TextDocumentPositionParams,
pub new_name: String,
pub work_done_progress_params: WorkDoneProgressParams,
}Fields
text_document_position: TextDocumentPositionParamsText Document and Position fields
new_name: StringThe new name of the symbol. If the given name is not valid the request must return a ResponseError with an appropriate message set.
work_done_progress_params: WorkDoneProgressParamsTrait Implementations
sourceimpl Clone for RenameParams
impl Clone for RenameParams
sourcefn clone(&self) -> RenameParams
fn clone(&self) -> RenameParams
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RenameParams
impl Debug for RenameParams
sourceimpl<'de> Deserialize<'de> for RenameParams
impl<'de> Deserialize<'de> for RenameParams
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<RenameParams> for RenameParams
impl PartialEq<RenameParams> for RenameParams
sourcefn eq(&self, other: &RenameParams) -> bool
fn eq(&self, other: &RenameParams) -> bool
This method tests for
self and other values to be equal, and is used
by ==.