Struct lsp_types::SemanticTokenModifier [−][src]
pub struct SemanticTokenModifier(_);
A set of predefined token modifiers. This set is not fixed and clients can specify additional token types via the corresponding client capabilities.
@since 3.16.0
Implementations