pub struct SemanticTokensClientCapabilitiesRequests {
pub range: Option<bool>,
pub full: Option<SemanticTokensFullOptions>,
}Fields
range: Option<bool>The client will send the textDocument/semanticTokens/range request if the server provides a corresponding handler.
full: Option<SemanticTokensFullOptions>The client will send the textDocument/semanticTokens/full request if the server provides a corresponding handler.