Struct lsp_types::SemanticTokensDeltaParams [−][src]
pub struct SemanticTokensDeltaParams {
pub work_done_progress_params: WorkDoneProgressParams,
pub partial_result_params: PartialResultParams,
pub text_document: TextDocumentIdentifier,
pub previous_result_id: String,
}Fields
work_done_progress_params: WorkDoneProgressParamspartial_result_params: PartialResultParamstext_document: TextDocumentIdentifierThe text document.
previous_result_id: StringThe result id of a previous response. The result Id can either point to a full response or a delta response depending on what was recevied last.