Struct lsp_types::SemanticTokensOptions [−][src]
pub struct SemanticTokensOptions {
pub work_done_progress_options: WorkDoneProgressOptions,
pub legend: SemanticTokensLegend,
pub range: Option<bool>,
pub full: Option<SemanticTokensFullOptions>,
}Expand description
@since 3.16.0
Fields
work_done_progress_options: WorkDoneProgressOptionslegend: SemanticTokensLegendThe legend used by the server
range: Option<bool>Server supports providing semantic tokens for a sepcific range of a document.
full: Option<SemanticTokensFullOptions>Server supports providing semantic tokens for a full document.