Struct lsp_types::ShowDocumentParams [−][src]
pub struct ShowDocumentParams {
pub uri: Url,
pub external: Option<bool>,
pub take_focus: Option<bool>,
pub selection: Option<Range>,
}Expand description
Params to show a document.
@since 3.16.0
Fields
uri: UrlThe document uri to show.
external: Option<bool>Indicates to show the resource in an external program.
To show for example https://code.visualstudio.com/
in the default WEB browser set external to true.
take_focus: Option<bool>An optional property to indicate whether the editor showing the document should take focus or not. Clients might ignore this property if an external program in started.
selection: Option<Range>An optional selection range if the document is a text document. Clients might ignore the property if an external program is started or the file is not a text file.