Struct lsp_types::SignatureHelpContext [−][src]
pub struct SignatureHelpContext {
pub trigger_kind: SignatureHelpTriggerKind,
pub trigger_character: Option<String>,
pub is_retrigger: bool,
pub active_signature_help: Option<SignatureHelp>,
}Fields
trigger_kind: SignatureHelpTriggerKindAction that caused signature help to be triggered.
trigger_character: Option<String>Character that caused signature help to be triggered.
This is undefined when triggerKind !== SignatureHelpTriggerKind.TriggerCharacter
is_retrigger: booltrue if signature help was already showing when it was triggered.
Retriggers occur when the signature help is already active and can be caused by actions such as
typing a trigger character, a cursor move, or document content changes.
active_signature_help: Option<SignatureHelp>The currently active SignatureHelp.
The activeSignatureHelp has its SignatureHelp.activeSignature field updated based on
the user navigating through available signatures.