Struct lsp_types::SignatureHelpOptions [−][src]
pub struct SignatureHelpOptions {
pub trigger_characters: Option<Vec<String>>,
pub retrigger_characters: Option<Vec<String>>,
pub work_done_progress_options: WorkDoneProgressOptions,
}Expand description
Signature help options.
Fields
trigger_characters: Option<Vec<String>>The characters that trigger signature help automatically.
retrigger_characters: Option<Vec<String>>List of characters that re-trigger signature help. These trigger characters are only active when signature help is already showing. All trigger characters are also counted as re-trigger characters.
work_done_progress_options: WorkDoneProgressOptionsTrait Implementations
Returns the “default value” for a type. Read more
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.