Struct lsp_types::SignatureInformation [−][src]
pub struct SignatureInformation {
pub label: String,
pub documentation: Option<Documentation>,
pub parameters: Option<Vec<ParameterInformation>>,
pub active_parameter: Option<u32>,
}Expand description
Represents the signature of something callable. A signature can have a label, like a function-name, a doc-comment, and a set of parameters.
Fields
label: StringThe label of this signature. Will be shown in the UI.
documentation: Option<Documentation>The human-readable doc-comment of this signature. Will be shown in the UI but can be omitted.
parameters: Option<Vec<ParameterInformation>>The parameters of this signature.
active_parameter: Option<u32>The index of the active parameter.
If provided, this is used in place of SignatureHelp.activeParameter.
@since 3.16.0