Struct lsp_types::TextDocumentItem [−][src]
pub struct TextDocumentItem {
pub uri: Url,
pub language_id: String,
pub version: i32,
pub text: String,
}Expand description
An item to transfer a text document from the client to the server.
Fields
uri: UrlThe text document’s URI.
language_id: StringThe text document’s language identifier.
version: i32The version number of this document (it will strictly increase after each change, including undo/redo).
text: StringThe content of the opened text document.
Implementations