Struct lsp_types::TextDocumentPositionParams [−][src]
pub struct TextDocumentPositionParams {
pub text_document: TextDocumentIdentifier,
pub position: Position,
}Expand description
A parameter literal used in requests to pass a text document and a position inside that document.
Fields
text_document: TextDocumentIdentifierThe text document.
position: PositionThe position inside the text document.
Implementations
pub fn new(
text_document: TextDocumentIdentifier,
position: Position
) -> TextDocumentPositionParams[src]Trait Implementations
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.