pub struct TextDocumentSaveRegistrationOptions {
pub include_text: Option<bool>,
pub text_document_registration_options: TextDocumentRegistrationOptions,
}Fields
include_text: Option<bool>The client is supposed to include the content on save.
text_document_registration_options: TextDocumentRegistrationOptionsTrait Implementations
sourceimpl Clone for TextDocumentSaveRegistrationOptions
impl Clone for TextDocumentSaveRegistrationOptions
sourcefn clone(&self) -> TextDocumentSaveRegistrationOptions
fn clone(&self) -> TextDocumentSaveRegistrationOptions
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl<'de> Deserialize<'de> for TextDocumentSaveRegistrationOptions
impl<'de> Deserialize<'de> for TextDocumentSaveRegistrationOptions
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<TextDocumentSaveRegistrationOptions> for TextDocumentSaveRegistrationOptions
impl PartialEq<TextDocumentSaveRegistrationOptions> for TextDocumentSaveRegistrationOptions
sourcefn eq(&self, other: &TextDocumentSaveRegistrationOptions) -> bool
fn eq(&self, other: &TextDocumentSaveRegistrationOptions) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
impl Eq for TextDocumentSaveRegistrationOptions
impl StructuralEq for TextDocumentSaveRegistrationOptions
impl StructuralPartialEq for TextDocumentSaveRegistrationOptions