Struct lsp_types::TextDocumentSyncOptions [−][src]
pub struct TextDocumentSyncOptions {
pub open_close: Option<bool>,
pub change: Option<TextDocumentSyncKind>,
pub will_save: Option<bool>,
pub will_save_wait_until: Option<bool>,
pub save: Option<TextDocumentSyncSaveOptions>,
}Fields
open_close: Option<bool>Open and close notifications are sent to the server.
change: Option<TextDocumentSyncKind>Change notifications are sent to the server. See TextDocumentSyncKind.None, TextDocumentSyncKind.Full and TextDocumentSyncKindIncremental.
will_save: Option<bool>Will save notifications are sent to the server.
will_save_wait_until: Option<bool>Will save wait until requests are sent to the server.
save: Option<TextDocumentSyncSaveOptions>Save notifications are sent to the server.