[−][src]Struct lsp_types::WorkspaceEdit
A workspace edit represents changes to many resources managed in the workspace.
Fields
changes: Option<HashMap<Url, Vec<TextEdit>>>Holds changes to existing resources.
document_changes: Option<DocumentChanges>Depending on the client capability workspace.workspaceEdit.resourceOperations document changes
are either an array of TextDocumentEdits to express changes to n different text documents
where each text document edit addresses a specific version of a text document. Or it can contain
above TextDocumentEdits mixed with create, rename and delete file / folder operations.
Whether a client supports versioned document edits is expressed via
workspace.workspaceEdit.documentChanges client capability.
If a client neither supports documentChanges nor workspace.workspaceEdit.resourceOperations then
only plain TextEdits using the changes property are supported.
Methods
impl WorkspaceEdit[src]