Struct lsp_types::WorkspaceEditClientCapabilities [−][src]
Fields
document_changes: Option<bool>The client supports versioned document changes in WorkspaceEdits
resource_operations: Option<Vec<ResourceOperationKind>>The resource operations the client supports. Clients should at least support 'create', 'rename' and 'delete' files and folders.
failure_handling: Option<FailureHandlingKind>The failure handling strategy of a client if applying the workspace edit failes.
normalizes_line_endings: Option<bool>Whether the client normalizes line endings to the client specific
setting.
If set to true the client will normalize line ending characters
in a workspace edit containg to the client specific new line
character.
@since 3.16.0
change_annotation_support: Option<ChangeAnnotationWorkspaceEditClientCapabilities>Whether the client in general supports change annotations on text edits, create file, rename file and delete file changes.
@since 3.16.0