Module lsp_types::error_codes [−][src]
In this module we only define constants for lsp specific error codes. There are other error codes that are defined in the JSON RPC specification.
Constants
| CONTENT_MODIFIED | |
| LSP_RESERVED_ERROR_RANGE_END | |
| LSP_RESERVED_ERROR_RANGE_START | |
| REQUEST_CANCELLED |