Enum lsp_types::notification::DidCreateFiles [−][src]
pub enum DidCreateFiles {}Expand description
The did create files notification is sent from the client to the server when files were created from within the client.