Enum lsp_types::request::GotoTypeDefinition [−][src]
The goto type definition request is sent from the client to the server to resolve the type definition location of a symbol at a given text document position.