Enum lsp_types::request::ShowDocument [−][src]
pub enum ShowDocument {}Expand description
The show document request is sent from a server to a client to ask the client to display a particular document in the user interface.