Struct lsp_types::CallHierarchyOutgoingCall [−][src]
Represents an outgoing call, e.g. calling a getter from a method or a method from a constructor etc.
Fields
to: CallHierarchyItemThe item that is called.
from_ranges: Vec<Range>The range at which this item is called. This is the range relative to the caller, e.g the item
passed to provideCallHierarchyOutgoingCalls
and not this.to.