Struct lsp_types::CodeAction [−][src]
Fields
title: StringA short, human-readable, title for this code action.
kind: Option<CodeActionKind>The kind of the code action. Used to filter code actions.
diagnostics: Option<Vec<Diagnostic>>The diagnostics that this code action resolves.
edit: Option<WorkspaceEdit>The workspace edit this code action performs.
command: Option<Command>A command this code action executes. If a code action provides an edit and a command, first the edit is executed and then the command.
is_preferred: Option<bool>Marks this as a preferred action. Preferred actions are used by the auto fix command and can be targeted
by keybindings.
A quick fix should be marked preferred if it properly addresses the underlying error.
A refactoring should be marked preferred if it is the most reasonable choice of actions to take.
since 3.15.0
disabled: Option<CodeActionDisabled>Marks that the code action cannot currently be applied.
Clients should follow the following guidelines regarding disabled code actions:
-
Disabled code actions are not shown in automatic lightbulb code action menu.
-
Disabled actions are shown as faded out in the code action menu when the user request a more specific type of code action, such as refactorings.
-
If the user has a keybinding that auto applies a code action and only a disabled code actions are returned, the client should show the user an error message with
reasonin the editor.
since 3.16.0
data: Option<Value>A data entry field that is preserved on a code action between
a textDocument/codeAction and a codeAction/resolve request.
since 3.16.0