Struct lsp_types::DocumentLink [−][src]
A document link is a range in a text document that links to an internal or external resource, like another text document or a web site.
Fields
range: RangeThe range this link applies to.
target: Option<Url>The uri this link points to.
tooltip: Option<String>The tooltip text when you hover over this link.
If a tooltip is provided, is will be displayed in a string that includes instructions on how to
trigger the link, such as {0} (ctrl + click). The specific instructions vary depending on OS,
user settings, and localization.
data: Option<Value>A data entry field that is preserved on a document link between a DocumentLinkRequest and a DocumentLinkResolveRequest.