Struct lsp_types::LocationLink [−][src]
pub struct LocationLink {
pub origin_selection_range: Option<Range>,
pub target_uri: Url,
pub target_range: Range,
pub target_selection_range: Range,
}Expand description
Represents a link between a source and a target location.
Fields
origin_selection_range: Option<Range>Span of the origin of this link.
Used as the underlined span for mouse interaction. Defaults to the word range at the mouse position.
target_uri: UrlThe target resource identifier of this link.
target_range: RangeThe full target range of this link.
target_selection_range: RangeThe span of this link.