Struct lsp_types::RenameParams [−][src]
pub struct RenameParams {
pub text_document_position: TextDocumentPositionParams,
pub new_name: String,
pub work_done_progress_params: WorkDoneProgressParams,
}Fields
text_document_position: TextDocumentPositionParamsText Document and Position fields
new_name: StringThe new name of the symbol. If the given name is not valid the request must return a ResponseError with an appropriate message set.
work_done_progress_params: WorkDoneProgressParamsTrait Implementations
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.