Struct lsp_types::SemanticTokens [−][src]
@since 3.16.0
Fields
result_id: Option<String>An optional result id. If provided and clients support delta updating the client will include the result id in the next semantic token request. A server can then instead of computing all semantic tokens again simply send a delta.
data: Vec<SemanticToken>The actual tokens. For a detailed description about how the data is structured please see https://github.com/microsoft/vscode-extension-samples/blob/5ae1f7787122812dcc84e37427ca90af5ee09f14/semantic-tokens-sample/vscode.proposed.d.ts#L71