Struct lsp_types::TextDocumentEdit [−][src]
Describes textual changes on a single text document. The text document is referred to as a
OptionalVersionedTextDocumentIdentifier to allow clients to check the text document version before an
edit is applied. A TextDocumentEdit describes all changes on a version Si and after they are
applied move the document to version Si+1. So the creator of a TextDocumentEdit doesn't need to
sort the array or do any kind of ordering. However the edits must be non overlapping.
Fields
text_document: OptionalVersionedTextDocumentIdentifierThe text document to change.
edits: Vec<OneOf<TextEdit, AnnotatedTextEdit>>The edits to be applied.
@since 3.16.0 - support for AnnotatedTextEdit. This is guarded by the
client capability workspace.workspaceEdit.changeAnnotationSupport